noumbissi: Noumbissi's Digit Heaping Index

View source: R/heaping_indices.R

noumbissiR Documentation

Noumbissi's Digit Heaping Index

Description

Noumbissi's method improves on Whipple's method by extending its basic principle to all ten digits. It compares the count of ages ending in a specific digit to the count in 5-year age groups centered on that digit.

Usage

noumbissi(
  x,
  digit = 0,
  ageMin = 20 + digit,
  ageMax = ageMin + 30,
  weight = NULL
)

Arguments

x

numeric vector of individual ages.

digit

integer (0-9) specifying which terminal digit to evaluate (default 0).

ageMin

minimum age to include (default 20 + digit).

ageMax

maximum age to include (default ageMin + 30).

weight

optional numeric vector of sampling weights.

Details

Calculate Noumbissi's index for a specific terminal digit.

The index compares the number of persons reporting ages ending in a specific digit to one-fifth of the population in the 5-year age groups centered on those ages.

Interpretation:

  • 1.0: no preference for the digit

  • >1.0: preference (attraction) to the digit

  • <1.0: avoidance of the digit

Value

A single numeric value representing Noumbissi's index for the specified digit.

Author(s)

Matthias Templ

References

Noumbissi, A. (1992). L'indice de Whipple modifie: une application aux donnees du Cameroun, de la Suede et de la Belgique. Population, 47(4), 1038-1041.

See Also

spoorenberg for Total Modified Whipple index, whipple for original Whipple's index.

Other heaping indices: bachi(), coale_li(), heaping_indices(), jdanov(), kannisto(), myers(), spoorenberg(), whipple()

Examples

# No heaping
set.seed(42)
age_uniform <- sample(20:70, 10000, replace = TRUE)
noumbissi(age_uniform, digit = 0)  # Should be close to 1
noumbissi(age_uniform, digit = 5)  # Should be close to 1

# Heaping on digit 0
age_heap0 <- sample(seq(20, 70, by = 10), 5000, replace = TRUE)
noumbissi(age_heap0, digit = 0)  # Should be > 1


heaping documentation built on Feb. 10, 2026, 1:08 a.m.