View source: R/heaping_indices.R
| noumbissi | R Documentation |
Noumbissi's method improves on Whipple's method by extending its basic principle to all ten digits. It compares the count of ages ending in a specific digit to the count in 5-year age groups centered on that digit.
noumbissi(
x,
digit = 0,
ageMin = 20 + digit,
ageMax = ageMin + 30,
weight = NULL
)
x |
numeric vector of individual ages. |
digit |
integer (0-9) specifying which terminal digit to evaluate (default 0). |
ageMin |
minimum age to include (default 20 + digit). |
ageMax |
maximum age to include (default ageMin + 30). |
weight |
optional numeric vector of sampling weights. |
Calculate Noumbissi's index for a specific terminal digit.
The index compares the number of persons reporting ages ending in a specific digit to one-fifth of the population in the 5-year age groups centered on those ages.
Interpretation:
1.0: no preference for the digit
>1.0: preference (attraction) to the digit
<1.0: avoidance of the digit
A single numeric value representing Noumbissi's index for the specified digit.
Matthias Templ
Noumbissi, A. (1992). L'indice de Whipple modifie: une application aux donnees du Cameroun, de la Suede et de la Belgique. Population, 47(4), 1038-1041.
spoorenberg for Total Modified Whipple index,
whipple for original Whipple's index.
Other heaping indices:
bachi(),
coale_li(),
heaping_indices(),
jdanov(),
kannisto(),
myers(),
spoorenberg(),
whipple()
# No heaping
set.seed(42)
age_uniform <- sample(20:70, 10000, replace = TRUE)
noumbissi(age_uniform, digit = 0) # Should be close to 1
noumbissi(age_uniform, digit = 5) # Should be close to 1
# Heaping on digit 0
age_heap0 <- sample(seq(20, 70, by = 10), 5000, replace = TRUE)
noumbissi(age_heap0, digit = 0) # Should be > 1
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.