| samp | R Documentation |
A stratified random sample of demographic and income data from a synthetic population generated using the simPop package based on EU-SILC data. This dataset can be used to demonstrate and test heaping correction methods.
samp
A data frame with 25 variables:
Household ID
Household size
Age in years
Gender
Region (Bundesland)
Person ID
Original sampling weight
Economic status
Citizenship status
Marital status
Education level
Employment status
Personal gross income category
Personal gross income
Employee cash or near cash income
Company car income
Self-employment income
Private pension income
Unemployment benefits
Old-age benefits
Survivor benefits
Sickness benefits
Disability benefits
Education-related allowances
Sampling weight from stratified sampling
Generated using simPop from EU-SILC 2013 public use file.
The full synthetic population can be regenerated using the script
inst/scripts/create_pop.R.
eusilc13puf for the original data source.
data(samp)
head(samp)
# Check age distribution
hist(samp$age, breaks = 50, main = "Age Distribution")
# Introduce artificial heaping and correct it
age_heaped <- round(samp$age / 5) * 5
age_corrected <- correctHeaps(age_heaped, heaps = "5year")
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.